@@ -16,7 +16,7 @@
   information.
 
 */
-/* $Id: silcske.c,v 1.92.2.3 2007/07/01 11:12:46 priikone Exp $ */
+/* $Id: silcske.c,v 1.92.2.4 2007/11/05 20:34:56 priikone Exp $ */
 
 #include "silc.h"
 #include "silcske.h"
@@ -3312,6 +3312,12 @@ SilcBool silc_ske_set_keys(SilcSKE ske,
       return FALSE;
   }
 
+  /* Allocate hash */
+  if (ret_hash) {
+    if (!silc_hash_alloc(silc_hash_get_name(prop->hash), ret_hash))
+      return FALSE;
+  }
+
   /* Set key material */
   memset(iv, 0, sizeof(iv));
   if (ske->responder) {
@@ -3320,10 +3326,22 @@ SilcBool silc_ske_set_keys(SilcSKE ske,
 			  keymat->enc_key_len, TRUE);
 
       if (silc_cipher_get_mode(*ret_send_key) == SILC_CIPHER_MODE_CTR) {
-        memcpy(iv, ske->hash, 4);
-        memcpy(iv + 4, keymat->receive_iv, iv_included ? 4 : 8);
+	/* Counter mode */
+	if (!ske->rekeying) {
+	  /* Set IV. */
+	  memcpy(iv, ske->hash, 4);
+	  if (!iv_included)
+	    memcpy(iv + 4, keymat->receive_iv, 8);
+	} else {
+	  /* Rekey, recompute the truncated hash value. */
+	  silc_hash_make(prop->hash, keymat->receive_iv, 8, iv);
+	  if (!iv_included)
+	    memcpy(iv + 4, keymat->receive_iv, 8);
+	}
+
         silc_cipher_set_iv(*ret_send_key, iv);
       } else {
+	/* Other modes */
 	silc_cipher_set_iv(*ret_send_key, keymat->receive_iv);
       }
     }
@@ -3332,10 +3350,22 @@ SilcBool silc_ske_set_keys(SilcSKE ske,
 			  keymat->enc_key_len, FALSE);
 
       if (silc_cipher_get_mode(*ret_receive_key) == SILC_CIPHER_MODE_CTR) {
-        memcpy(iv, ske->hash, 4);
-        memcpy(iv + 4, keymat->send_iv, iv_included ? 4 : 8);
+	/* Counter mode */
+	if (!ske->rekeying) {
+	  /* Set IV. */
+	  memcpy(iv, ske->hash, 4);
+	  if (!iv_included)
+	    memcpy(iv + 4, keymat->send_iv, 8);
+	} else {
+	  /* Rekey, recompute the truncated hash value. */
+	  silc_hash_make(prop->hash, keymat->send_iv, 8, iv);
+	  if (!iv_included)
+	    memcpy(iv + 4, keymat->send_iv, 8);
+	}
+
         silc_cipher_set_iv(*ret_receive_key, iv);
       } else {
+	/* Other modes */
 	silc_cipher_set_iv(*ret_receive_key, keymat->send_iv);
       }
     }
@@ -3351,10 +3381,22 @@ SilcBool silc_ske_set_keys(SilcSKE ske,
 			  keymat->enc_key_len, TRUE);
 
       if (silc_cipher_get_mode(*ret_send_key) == SILC_CIPHER_MODE_CTR) {
-        memcpy(iv, ske->hash, 4);
-        memcpy(iv + 4, keymat->send_iv, iv_included ? 4 : 8);
+	/* Counter mode */
+	if (!ske->rekeying) {
+	  /* Set IV. */
+	  memcpy(iv, ske->hash, 4);
+	  if (!iv_included)
+	    memcpy(iv + 4, keymat->send_iv, 8);
+	} else {
+	  /* Rekey, recompute the truncated hash value. */
+	  silc_hash_make(prop->hash, keymat->send_iv, 8, iv);
+	  if (!iv_included)
+	    memcpy(iv + 4, keymat->send_iv, 8);
+	}
+
 	silc_cipher_set_iv(*ret_send_key, iv);
       } else {
+	/* Other modes */
 	silc_cipher_set_iv(*ret_send_key, keymat->send_iv);
       }
     }
@@ -3363,10 +3405,23 @@ SilcBool silc_ske_set_keys(SilcSKE ske,
 			  keymat->enc_key_len, FALSE);
 
       if (silc_cipher_get_mode(*ret_receive_key) == SILC_CIPHER_MODE_CTR) {
-        memcpy(iv, ske->hash, 4);
-        memcpy(iv + 4, keymat->receive_iv, iv_included ? 4 : 8);
+	/* Counter mode */
+	if (!ske->rekeying) {
+	  /* Set IV.  If IV Included flag was negotiated we only set the
+	     truncated hash value. */
+	  memcpy(iv, ske->hash, 4);
+	  if (!iv_included)
+	    memcpy(iv + 4, keymat->receive_iv, 8);
+	} else {
+	  /* Rekey, recompute the truncated hash value. */
+	  silc_hash_make(prop->hash, keymat->receive_iv, 8, iv);
+	  if (!iv_included)
+	    memcpy(iv + 4, keymat->receive_iv, 8);
+	}
+
 	silc_cipher_set_iv(*ret_receive_key, iv);
       } else {
+	/* Other modes */
 	silc_cipher_set_iv(*ret_receive_key, keymat->receive_iv);
       }
     }
@@ -3378,12 +3433,6 @@ SilcBool silc_ske_set_keys(SilcSKE ske,
 			keymat->hmac_key_len);
   }
 
-  /* Allocate hash */
-  if (ret_hash) {
-    if (!silc_hash_alloc(silc_hash_get_name(prop->hash), ret_hash))
-      return FALSE;
-  }
-
   return TRUE;
 }
 
