@@ -4,29 +4,28 @@
 
   Author: Pekka Riikonen <priikone@silcnet.org>
 
-  Copyright (C) 1997 - 2003 Pekka Riikonen
+  Copyright (C) 1997 - 2007 Pekka Riikonen
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
+  The contents of this file are subject to one of the Licenses specified 
+  in the COPYING file;  You may not use this file except in compliance 
+  with the License.
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+  The software distributed under the License is distributed on an "AS IS"
+  basis, in the hope that it will be useful, but WITHOUT WARRANTY OF ANY
+  KIND, either expressed or implied.  See the COPYING file for more
+  information.
 
 */
-/* $Id: silcfileutil.c,v 1.4.2.3 2003/11/09 15:37:47 priikone Exp $ */
+/* $Id: silcfileutil.c,v 1.15 2007/05/13 15:30:37 priikone Exp $ */
 
-#include "silcincludes.h"
+#include "silc.h"
 
 /* Opens a file indicated by the filename `filename' with flags indicated
    by the `flags'. */
 
 int silc_file_open(const char *filename, int flags)
 {
-  int fd = open(filename, flags, 0600);
-  return fd;
+  return silc_file_open_mode(filename, flags, 0600);
 }
 
 /* Opens a file indicated by the filename `filename' with flags indicated
@@ -83,9 +82,11 @@ int silc_file_writefile(const char *filename, const char *buffer,
     return -1;
   }
 
-  silc_file_close(fd);
+#ifdef SILC_UNIX
+  fsync(fd);
+#endif /* SILC_UNIX */
 
-  return 0;
+  return silc_file_close(fd);
 }
 
 /* Writes a buffer to the file.  If the file is created specific mode is
@@ -113,9 +114,11 @@ int silc_file_writefile_mode(const char *filename, const char *buffer,
     return -1;
   }
 
-  silc_file_close(fd);
+#ifdef SILC_UNIX
+  fsync(fd);
+#endif /* SILC_UNIX */
 
-  return 0;
+  return silc_file_close(fd);
 }
 
 /* Reads a file to a buffer. The allocated buffer is returned. Length of
@@ -177,11 +180,15 @@ SilcUInt64 silc_file_size(const char *filename)
   int ret;
   struct stat stats;
 
-#ifndef SILC_WIN32
-  ret = lstat(filename, &stats);
-#else
+#ifdef SILC_WIN32
   ret = stat(filename, &stats);
-#endif
+#endif /* SILC_WIN32 */
+#ifdef SILC_UNIX
+  ret = lstat(filename, &stats);
+#endif /* SILC_UNIX */
+#ifdef SILC_SYMBIAN
+  ret = stat(filename, &stats);
+#endif /* SILC_SYMBIAN */
   if (ret < 0)
     return 0;
 
